@@ -47,7 +47,7 @@ class Model:
   (e.g. interpolation can be implemented as a composition of two models along
   with an interpolation weight).
 
-  Works for Haiku and jax.experimental.stax.
+  Works for Haiku and jax.example_libraries.stax.
 
   The expected usage of Model is as follows::
 
@@ -64,7 +64,7 @@ class Model:
     for batch in batches:
       rng, use_rng = jax.random.split(rng)
       grads = grad_fn(params, batch, use_rng)
-      params = jax.tree_util.tree_multimap(lambda a, b: a - step_size * b,
+      params = jax.tree_util.tree_map(lambda a, b: a - step_size * b,
                                            params, grads)
 
     # Evaluation.
@@ -255,7 +255,7 @@ def _evaluate_model_step(model: Model, params: Params, batch: BatchExample,
       k: metrics.evaluate_batch(metric, batch, pred, mask)
       for k, metric in model.eval_metrics.items()
   }
-  return jax.tree_util.tree_multimap(
+  return jax.tree_util.tree_map(
       lambda a, b: a.merge(b),
       stat,
       new_stat,
