@@ -15,36 +15,37 @@
 
 import os
 
-from fedjax.core import test_util
+from absl.testing import absltest
+
 from fedjax.training import checkpoint
-import tensorflow as tf
+import jax.numpy as jnp
+import numpy.testing as npt
 
 
-class CheckpointTest(tf.test.TestCase):
+class CheckpointTest(absltest.TestCase):
 
   def setUp(self):
     super().setUp()
-    self._root_dir = self.get_temp_dir()
+    self._root_dir = self.create_tempdir()
 
   def _write_file(self, basename):
     path = os.path.join(self._root_dir, basename)
-    with tf.io.gfile.GFile(path, mode='w') as f:
+    with open(path, 'w') as f:
       f.write(basename)
 
   def test_save_checkpoint(self):
-    checkpoint.save_checkpoint(self._root_dir, test_util.create_mock_state())
+    checkpoint.save_checkpoint(self._root_dir, {'w': jnp.ones(10)})
 
-    self.assertEqual(
-        tf.io.gfile.listdir(self._root_dir), ['checkpoint_00000000'])
+    self.assertEqual(os.listdir(self._root_dir), ['checkpoint_00000000'])
 
   def test_save_checkpoint_keep(self):
-    state = test_util.create_mock_state()
+    state = {'w': jnp.ones(10)}
 
     for i in range(3):
       checkpoint.save_checkpoint(self._root_dir, state, round_num=i, keep=2)
 
     self.assertCountEqual(
-        tf.io.gfile.listdir(self._root_dir),
+        os.listdir(self._root_dir),
         ['checkpoint_00000001', 'checkpoint_00000002'])
 
   def test_get_checkpoint_paths(self):
@@ -65,17 +66,17 @@ class CheckpointTest(tf.test.TestCase):
         ['checkpoint_00000000', 'checkpoint_00000003', 'checkpoint_00000100'])
 
   def test_load_latest_checkpoint(self):
-    state_1 = test_util.create_mock_state(seed=1)
-    state_2 = test_util.create_mock_state(seed=2)
-    checkpoint.save_checkpoint(self._root_dir, state_1, round_num=10, keep=2)
-    checkpoint.save_checkpoint(self._root_dir, state_2, round_num=3, keep=2)
+    state_1 = {'w': jnp.ones(10)}
+    state_2 = {'w': jnp.ones(10) * 2}
+    checkpoint.save_checkpoint(self._root_dir, state_1, round_num=1, keep=2)
+    checkpoint.save_checkpoint(self._root_dir, state_2, round_num=2, keep=2)
 
     latest_state, latest_round_num = checkpoint.load_latest_checkpoint(
         root_dir=self._root_dir)
 
-    self.assertEqual(latest_round_num, 10)
-    tf.nest.map_structure(self.assertAllEqual, latest_state, state_1)
+    self.assertEqual(latest_round_num, 2)
+    npt.assert_array_equal(latest_state['w'], state_2['w'])
 
 
 if __name__ == '__main__':
-  tf.test.main()
+  absltest.main()
